@@ -1670,7 +1670,7 @@ def update_with(obj, path, updater, customizer=None):
         base_set(target, key, path_obj, allow_override=False)
 
         try:
-            target = get(target, key)
+            target = base_get(target, key, default=None)
         except TypeError as exc:  # pragma: no cover
             try:
                 target = target[int(key)]
